@@ -134,6 +134,12 @@
 #define ELF_TARG_DATA	ELFDATA2LSB
 #endif
 
+#elif defined(__nios2__)
+
+#define ELF_TARG_MACH	EM_ALTERA_NIOS2
+#define ELF_TARG_CLASS	ELFCLASS32
+#define ELF_TARG_DATA	ELFDATA2LSB
+
 #elif defined(__powerpc__)
 
 #define ELF_TARG_MACH	EM_PPC
@@ -146,6 +152,18 @@
 #define ELF_TARG_CLASS	ELFCLASS64
 #define ELF_TARG_DATA	ELFDATA2MSB
 
+#elif defined(__riscv)
+
+#define ELF_TARG_MACH	EM_RISCV
+#if __riscv_xlen == 32
+#define ELF_TARG_CLASS	ELFCLASS32
+#elif __riscv_xlen == 64
+#define ELF_TARG_CLASS	ELFCLASS64
+#else
+#error Unsupported ELF class
+#endif
+#define ELF_TARG_DATA	ELFDATA2LSB
+
 #elif defined(__sparc__)
 
 #if defined(__arch64__)
@@ -179,6 +197,12 @@
 #endif
 #define ELF_TARG_DATA	ELFDATA2MSB
 
+#elif defined(__tilegx__)
+
+#define ELF_TARG_MACH	EM_TILEGX
+#define ELF_TARG_CLASS	ELFCLASS64
+#define ELF_TARG_DATA	ELFDATA2LSB
+
 #elif defined(__or1k__)
 
 #define ELF_TARG_MACH	EM_OPENRISC
